@@ -56,6 +56,8 @@ static ClutterStageWindowIface *clutter_stage_window_parent_iface = NULL;
 static void clutter_stage_window_iface_init     (ClutterStageWindowIface     *iface);
 static void clutter_event_translator_iface_init (ClutterEventTranslatorIface *iface);
 
+static ClutterStageCogl *clutter_x11_get_stage_window_from_window (Window win);
+
 static GHashTable *clutter_stages_by_xid = NULL;
 
 #define clutter_stage_x11_get_type      _clutter_stage_x11_get_type
@@ -529,6 +531,37 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
    * queue a relayout etc. */
 }
 
+void
+_clutter_stage_x11_events_device_changed (ClutterStageX11 *stage_x11,
+                                          ClutterInputDevice *device,
+                                          ClutterDeviceManager *device_manager)
+{
+  ClutterStageCogl *stage_cogl = CLUTTER_STAGE_COGL (stage_x11);
+  int event_flags = 0;
+
+  if (clutter_input_device_get_device_mode (device) == CLUTTER_INPUT_MODE_FLOATING)
+    event_flags = CLUTTER_STAGE_X11_EVENT_MASK;
+
+  _clutter_device_manager_select_stage_events (device_manager,
+                                               stage_cogl->wrapper,
+                                               event_flags);
+}
+
+static void
+stage_events_device_added (ClutterDeviceManager *device_manager,
+                           ClutterInputDevice *device,
+                           gpointer user_data)
+{
+  ClutterStageWindow *stage_window = user_data;
+  ClutterStageCogl *stage_cogl = CLUTTER_STAGE_COGL (stage_window);
+  int event_flags = CLUTTER_STAGE_X11_EVENT_MASK;
+
+  if (clutter_input_device_get_device_mode (device) == CLUTTER_INPUT_MODE_FLOATING)
+    _clutter_device_manager_select_stage_events (device_manager,
+                                                 stage_cogl->wrapper,
+                                                 event_flags);
+}
+
 static gboolean
 clutter_stage_x11_realize (ClutterStageWindow *stage_window)
 {
@@ -616,6 +649,9 @@ clutter_stage_x11_realize (ClutterStageWindow *stage_window)
                                                stage_cogl->wrapper,
                                                event_flags);
 
+  g_signal_connect (device_manager, "device-added",
+                    G_CALLBACK (stage_events_device_added), stage_window);
+
   clutter_stage_x11_fix_window_size (stage_x11,
                                      stage_x11->xwin_width,
                                      stage_x11->xwin_height);
@@ -927,18 +963,23 @@ clutter_stage_x11_translate_event (ClutterEventTranslator *translator,
                                    gpointer                native,
                                    ClutterEvent           *event)
 {
-  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (translator);
-  ClutterStageCogl *stage_cogl = CLUTTER_STAGE_COGL (translator);
+  ClutterStageX11 *stage_x11;
+  ClutterStageCogl *stage_cogl;
   ClutterTranslateReturn res = CLUTTER_TRANSLATE_CONTINUE;
-  ClutterBackendX11 *backend_x11 = CLUTTER_BACKEND_X11 (stage_cogl->backend);
-  Window stage_xwindow = stage_x11->xwin;
+  ClutterBackendX11 *backend_x11;
+  Window stage_xwindow;
   XEvent *xevent = native;
   ClutterStage *stage;
 
-  stage = clutter_x11_get_stage_from_window (xevent->xany.window);
-  if (stage == NULL)
+  stage_cogl = clutter_x11_get_stage_window_from_window (xevent->xany.window);
+  if (stage_cogl == NULL)
     return CLUTTER_TRANSLATE_CONTINUE;
 
+  stage = stage_cogl->wrapper;
+  stage_x11 = CLUTTER_STAGE_X11 (stage_cogl);
+  backend_x11 = CLUTTER_BACKEND_X11 (stage_cogl->backend);
+  stage_xwindow = stage_x11->xwin;
+
   switch (xevent->type)
     {
     case ConfigureNotify:
@@ -1194,11 +1235,21 @@ clutter_x11_get_stage_window (ClutterStage *stage)
   return CLUTTER_STAGE_X11 (impl)->xwin;
 }
 
+static ClutterStageCogl *
+clutter_x11_get_stage_window_from_window (Window win)
+{
+  if (clutter_stages_by_xid == NULL)
+    return NULL;
+
+  return g_hash_table_lookup (clutter_stages_by_xid,
+                              GINT_TO_POINTER (win));
+}
+
 /**
  * clutter_x11_get_stage_from_window:
  * @win: an X Window ID
  *
- * Gets the stage for a particular X window.  
+ * Gets the stage for a particular X window.
  *
  * Return value: (transfer none): A #ClutterStage, or% NULL if a stage
  *   does not exist for the window
@@ -1210,11 +1261,7 @@ clutter_x11_get_stage_from_window (Window win)
 {
   ClutterStageCogl *stage_cogl;
 
-  if (clutter_stages_by_xid == NULL)
-    return NULL;
-
-  stage_cogl = g_hash_table_lookup (clutter_stages_by_xid,
-				    GINT_TO_POINTER (win));
+  stage_cogl = clutter_x11_get_stage_window_from_window (win);
 
   if (stage_cogl != NULL)
     return stage_cogl->wrapper;
